eyepy package
=============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   eyepy.core
   eyepy.data
   eyepy.io
   eyepy.metrics
   eyepy.utils

Module contents
---------------

.. automodule:: eyepy
   :members:
   :undoc-members:
   :show-inheritance:
